package digital.laboratory.platform.entrustment.dto;

import digital.laboratory.platform.sys.entity.DrugLite;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import java.util.List;

@Data
@ApiModel(value = "ApprovedUpdateEntrustDTO", description = "审批通过后，更新委托信息的DTO类")
public class ApprovedUpdateEntrustDTO {

    @ApiModelProperty(value = "申请id")
    @NotBlank(message = "申请id不能为空!")
    private String id;

    @ApiModelProperty(value = "关联的委托id")
    @NotBlank(message = "关联的委托id不能为空!")
    private String entrustId;

    @ApiModelProperty(value = "案件简要")
    private String caseBrief;

    @ApiModelProperty(value = "委托检材列表")
    private List<MaterialDTO> materialList;

    @ApiModelProperty(value = "是否完成， true:已完成（标记该申请已完成，该申请将不在允许修改）, false:未完成(不改变状态)")
    private Boolean finished;

    // 使用内部类MaterialDTO
    @Data
    @ApiModel(value = "MaterialDTO", description = "委托检材")
    class MaterialDTO {

        @ApiModelProperty(value = "检材id")
        private String id;

        @ApiModelProperty(value = "检材名称(疑似物种类)")
        private String name;

        @ApiModelProperty(value = "分析项目  1.定性分析   2.定量分析 3.定性定量分析 4.关联性判断 5。其他")
        private Integer analysisOption;

        @ApiModelProperty(value = "候选毒品列表(drug 对象的 json array)")
        private List<DrugLite> candidateDrugs;
    }

}
